==> dif-database-audit-2.4.2-1-20191003.162433-1-sources.jar: pt/digitalis/dif/dem/managers/impl/audit/model/IAuditService.java <==
package pt.digitalis.dif.dem.managers.impl.audit.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.audit.model.dao.IAuditLogDAO;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.audit.model.dao.IAuditLogDetailDAO;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLogDetail;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IAuditService {

	/**
	 * Obtains a new AuditLog DAO
	 *
	 * @return A new IAuditLogDAO
	 */
    public IAuditLogDAO getAuditLogDAO();

    /**
     * Obtains a new DataSet for the AuditLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLog> getAuditLogDataSet();

	/**
	 * Obtains a new AuditLogDetail DAO
	 *
	 * @return A new IAuditLogDetailDAO
	 */
    public IAuditLogDetailDAO getAuditLogDetailDAO();

    /**
     * Obtains a new DataSet for the AuditLogDetail entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLogDetail> getAuditLogDetailDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}

==> dif-database-audit-2.6.0-sources.jar: pt/digitalis/dif/dem/managers/impl/audit/model/IAuditService.java <==
package pt.digitalis.dif.dem.managers.impl.audit.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.audit.model.dao.auto.IAuditLogDAO;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.audit.model.dao.auto.IAuditLogDetailDAO;
import pt.digitalis.dif.dem.managers.impl.audit.model.data.AuditLogDetail;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IAuditService {

	/**
	 * Obtains a new AuditLog DAO
	 *
	 * @return A new IAuditLogDAO
	 */
    public IAuditLogDAO getAuditLogDAO();

    /**
     * Obtains a new DataSet for the AuditLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLog> getAuditLogDataSet();

	/**
	 * Obtains a new AuditLogDetail DAO
	 *
	 * @return A new IAuditLogDetailDAO
	 */
    public IAuditLogDetailDAO getAuditLogDetailDAO();

    /**
     * Obtains a new DataSet for the AuditLogDetail entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLogDetail> getAuditLogDetailDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}
